@@ -23,29 +23,87 @@
 #include <CollectionModifyJob>
 #include <CollectionFilterProxyModel>
 #include <KRecursiveFilterProxyModel>
+#include <AkonadiCore/AttributeFactory>
 
 #include <ChangeRecorder>
 #include <EntityTreeModel>
 #include <Collection>
 #include <KMime/Message>
 
-#include <KCheckableProxyModel>
-
 #include <KLocalizedString>
 #include <QPushButton>
 #include <KLineEdit>
 #include "newmailnotifier_debug.h"
 
 #include <QVBoxLayout>
+#include <QIdentityProxyModel>
 #include <QHBoxLayout>
 #include <QTreeView>
 #include <QLabel>
 #include <QTimer>
 
+NewMailNotifierCollectionProxyModel::NewMailNotifierCollectionProxyModel(QObject *parent)
+    : QIdentityProxyModel(parent)
+{
+}
+
+QVariant NewMailNotifierCollectionProxyModel::data(const QModelIndex &index, int role) const
+{
+    if (role == Qt::CheckStateRole)
+    {
+        if (index.isValid()) {
+            const Akonadi::Collection collection =
+                    data(index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+            if (mNotificationCollection.contains(collection)) {
+                return mNotificationCollection.value(collection) ? Qt::Checked : Qt::Unchecked;
+            } else {
+                Akonadi::NewMailNotifierAttribute *attr = collection.attribute<Akonadi::NewMailNotifierAttribute>();
+                if (!attr || !attr->ignoreNewMail()) {
+                    return Qt::Checked;
+                }
+                return Qt::Unchecked;
+            }
+        }
+    }
+    return QIdentityProxyModel::data(index, role);
+}
+
+bool NewMailNotifierCollectionProxyModel::setData(const QModelIndex &index, const QVariant &value, int role)
+{
+    if (role == Qt::CheckStateRole)
+    {
+        if (index.isValid()) {
+            const Akonadi::Collection collection =
+                data(index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+            mNotificationCollection[collection] = (value == Qt::Checked);
+            emit dataChanged(index, index);
+            return true;
+        }
+    }
+
+    return QIdentityProxyModel::setData(index, value, role);
+}
+
+Qt::ItemFlags NewMailNotifierCollectionProxyModel::flags(const QModelIndex &index) const
+{
+    if (index.isValid()) {
+        return QIdentityProxyModel::flags(index) | Qt::ItemIsUserCheckable;
+    } else {
+        return QIdentityProxyModel::flags(index);
+    }
+}
+
+QHash<Akonadi::Collection, bool> NewMailNotifierCollectionProxyModel::notificationCollection() const
+{
+    return mNotificationCollection;
+}
+
+
 NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWidget *parent)
     : QWidget(parent),
       mNeedUpdate(false)
 {
+    Akonadi::AttributeFactory::registerAttribute<Akonadi::NewMailNotifierAttribute>();
     QVBoxLayout *vbox = new QVBoxLayout;
 
     QLabel *label = new QLabel(i18n("Select which folders to monitor for new message notifications:"));
@@ -67,14 +125,12 @@ NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWi
     mimeTypeProxy->addMimeTypeFilters(QStringList() << KMime::Message::mimeType());
     mimeTypeProxy->setSourceModel(mModel);
 
-    // Create the Check proxy model.
-    mSelectionModel = new QItemSelectionModel(mimeTypeProxy);
-    mCheckProxy = new KCheckableProxyModel(this);
-    mCheckProxy->setSelectionModel(mSelectionModel);
-    mCheckProxy->setSourceModel(mimeTypeProxy);
+
+    mNewMailNotifierProxyModel = new NewMailNotifierCollectionProxyModel(this);
+    mNewMailNotifierProxyModel->setSourceModel(mimeTypeProxy);
 
     mCollectionFilter = new KRecursiveFilterProxyModel(this);
-    mCollectionFilter->setSourceModel(mCheckProxy);
+    mCollectionFilter->setSourceModel(mNewMailNotifierProxyModel);
     mCollectionFilter->setDynamicSortFilter(true);
     mCollectionFilter->setFilterCaseSensitivity(Qt::CaseInsensitive);
 
@@ -114,10 +170,6 @@ NewMailNotifierSelectCollectionWidget::~NewMailNotifierSelectCollectionWidget()
 
 void NewMailNotifierSelectCollectionWidget::slotCollectionTreeFetched()
 {
-    if (!mNeedUpdate) {
-        mNeedUpdate = true;
-        QTimer::singleShot(1000, this, &NewMailNotifierSelectCollectionWidget::slotUpdateCollectionStatus);
-    }
     mFolderView->expandAll();
 }
 
@@ -127,11 +179,6 @@ void NewMailNotifierSelectCollectionWidget::slotSetCollectionFilter(const QStrin
     mFolderView->expandAll();
 }
 
-void NewMailNotifierSelectCollectionWidget::slotUpdateCollectionStatus()
-{
-    updateStatus(QModelIndex());
-}
-
 void NewMailNotifierSelectCollectionWidget::slotSelectAllCollections()
 {
     forceStatus(QModelIndex(), true);
@@ -142,46 +189,25 @@ void NewMailNotifierSelectCollectionWidget::slotUnselectAllCollections()
     forceStatus(QModelIndex(), false);
 }
 
-void NewMailNotifierSelectCollectionWidget::updateStatus(const QModelIndex &parent)
-{
-    const int nbCol = mCheckProxy->rowCount(parent);
-    for (int i = 0; i < nbCol; ++i) {
-        const QModelIndex child = mCheckProxy->index(i, 0, parent);
-
-        const Akonadi::Collection collection =
-            mCheckProxy->data(child, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
-
-        Akonadi::NewMailNotifierAttribute *attr = collection.attribute<Akonadi::NewMailNotifierAttribute>();
-        if (!attr || !attr->ignoreNewMail()) {
-            mCheckProxy->setData(child, Qt::Checked, Qt::CheckStateRole);
-        }
-        updateStatus(child);
-    }
-    mNeedUpdate = false;
-}
-
 void NewMailNotifierSelectCollectionWidget::forceStatus(const QModelIndex &parent, bool status)
 {
-    const int nbCol = mCheckProxy->rowCount(parent);
+    const int nbCol = mNewMailNotifierProxyModel->rowCount(parent);
     for (int i = 0; i < nbCol; ++i) {
-        const QModelIndex child = mCheckProxy->index(i, 0, parent);
-        mCheckProxy->setData(child, status ? Qt::Checked : Qt::Unchecked, Qt::CheckStateRole);
+        const QModelIndex child = mNewMailNotifierProxyModel->index(i, 0, parent);
+        mNewMailNotifierProxyModel->setData(child, status ? Qt::Checked : Qt::Unchecked, Qt::CheckStateRole);
         forceStatus(child, status);
     }
 }
 
-void NewMailNotifierSelectCollectionWidget::updateCollectionsRecursive(const QModelIndex &parent)
+void NewMailNotifierSelectCollectionWidget::updateCollectionsRecursive()
 {
-    const int nbCol = mCheckProxy->rowCount(parent);
-    for (int i = 0; i < nbCol; ++i) {
-        const QModelIndex child = mCheckProxy->index(i, 0, parent);
-
-        Akonadi::Collection collection =
-            mCheckProxy->data(child, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
-
+    QHashIterator<Akonadi::Collection, bool> i(mNewMailNotifierProxyModel->notificationCollection());
+    while (i.hasNext()) {
+        i.next();
+        Akonadi::Collection collection = i.key();
         Akonadi::NewMailNotifierAttribute *attr = collection.attribute<Akonadi::NewMailNotifierAttribute>();
         Akonadi::CollectionModifyJob *modifyJob = Q_NULLPTR;
-        const bool selected = (mCheckProxy->data(child, Qt::CheckStateRole).value<int>() != 0);
+        const bool selected = i.value();
         if (selected && attr && attr->ignoreNewMail()) {
             collection.removeAttribute<Akonadi::NewMailNotifierAttribute>();
             modifyJob = new Akonadi::CollectionModifyJob(collection);
@@ -196,7 +222,6 @@ void NewMailNotifierSelectCollectionWidget::updateCollectionsRecursive(const QMo
         if (modifyJob) {
             connect(modifyJob, &Akonadi::CollectionModifyJob::finished, this, &NewMailNotifierSelectCollectionWidget::slotModifyJobDone);
         }
-        updateCollectionsRecursive(child);
     }
 }
 
@@ -216,3 +241,5 @@ void NewMailNotifierSelectCollectionWidget::slotModifyJobDone(KJob *job)
     }
 }
 
+
+
