@@ -23,6 +23,7 @@
 #include <QWidget>
 #include <Collection>
 #include <QModelIndex>
+#include <QIdentityProxyModel>
 
 class QItemSelectionModel;
 class KRecursiveFilterProxyModel;
@@ -32,9 +33,25 @@ class EntityTreeModel;
 class ChangeRecorder;
 }
 class QTreeView;
-class KCheckableProxyModel;
 class KJob;
 
+
+class NewMailNotifierCollectionProxyModel : public QIdentityProxyModel
+{
+public:
+    explicit NewMailNotifierCollectionProxyModel(QObject *parent = Q_NULLPTR);
+
+    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
+
+    bool setData(const QModelIndex &index, const QVariant &_data, int role) Q_DECL_OVERRIDE;
+    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
+
+    QHash<Akonadi::Collection, bool> notificationCollection() const;
+
+private:
+    QHash<Akonadi::Collection, bool> mNotificationCollection;
+};
+
 class NewMailNotifierSelectCollectionWidget : public QWidget
 {
     Q_OBJECT
@@ -42,26 +59,24 @@ public:
     explicit NewMailNotifierSelectCollectionWidget(QWidget *parent = Q_NULLPTR);
     ~NewMailNotifierSelectCollectionWidget();
 
-    void updateCollectionsRecursive(const QModelIndex &parent);
+    void updateCollectionsRecursive();
 
 private Q_SLOTS:
     void slotSelectAllCollections();
     void slotUnselectAllCollections();
     void slotModifyJobDone(KJob *job);
-    void slotUpdateCollectionStatus();
     void slotSetCollectionFilter(const QString &);
 
     void slotCollectionTreeFetched();
 
 private:
-    void updateStatus(const QModelIndex &parent);
     void forceStatus(const QModelIndex &parent, bool status);
     QTreeView *mFolderView;
     QItemSelectionModel *mSelectionModel;
     Akonadi::EntityTreeModel *mModel;
     Akonadi::ChangeRecorder *mChangeRecorder;
-    KCheckableProxyModel *mCheckProxy;
     KRecursiveFilterProxyModel *mCollectionFilter;
+    NewMailNotifierCollectionProxyModel *mNewMailNotifierProxyModel;
     bool mNeedUpdate;
 };
 
