@@ -20,9 +20,9 @@
 #ifndef AKONADI_GIDMIGRATIONJOB_H
 #define AKONADI_GIDMIGRATIONJOB_H
 
-#include <akonadi/item.h>
-#include <akonadi/collection.h>
-#include <akonadi/job.h>
+#include <AkonadiCore/item.h>
+#include <AkonadiCore/collection.h>
+#include <AkonadiCore/job.h>
 #include <QStringList>
 #include <QQueue>
 
@@ -42,19 +42,19 @@ public:
      * @param mimeTypeFilter The list of mimetypes of objects to be migrated.
      * @param parent The parent object.
      */
-    explicit GidMigrationJob(const QStringList &mimeTypeFilter, QObject *parent = 0);
+    explicit GidMigrationJob(const QStringList &mimeTypeFilter, QObject *parent = Q_NULLPTR);
 
     /**
      * Destroys the item fetch job.
      */
     virtual ~GidMigrationJob();
 
-    virtual void doStart();
+    void doStart() Q_DECL_OVERRIDE;
 
-private slots:
+private Q_SLOTS:
     void collectionsReceived(const Akonadi::Collection::List &);
-    void collectionsFetched(KJob*);
-    void itemsUpdated(KJob*);
+    void collectionsFetched(KJob *);
+    void itemsUpdated(KJob *);
 
 private:
     void processCollection();
@@ -69,13 +69,13 @@ class UpdateJob: public Akonadi::Job
 {
     Q_OBJECT
 public:
-    explicit UpdateJob(const Akonadi::Collection &col, QObject *parent = 0);
+    explicit UpdateJob(const Akonadi::Collection &col, QObject *parent = Q_NULLPTR);
     virtual ~UpdateJob();
 
-    virtual void doStart();
-    virtual void slotResult(KJob *job);
+    void doStart() Q_DECL_OVERRIDE;
+    void slotResult(KJob *job) Q_DECL_OVERRIDE;
 
-private slots:
+private Q_SLOTS:
     void itemsReceived(const Akonadi::Item::List &items);
 private:
     bool processNext();
