@@ -20,20 +20,20 @@
 #ifndef LOCKMETHODPAGE_H
 #define LOCKMETHODPAGE_H
 
-#include <QtGui/QWidget>
+#include <QWidget>
 
 #include "ui_lockfilepage.h"
 
 class LockMethodPage : public QWidget
 {
-  Q_OBJECT
-  public:
-    explicit LockMethodPage( QWidget *parent = 0 );
+    Q_OBJECT
+public:
+    explicit LockMethodPage(QWidget *parent = Q_NULLPTR);
 
-  private:
+private:
     void checkAvailableLockMethods();
 
-  private:
+private:
     Ui::LockFilePage ui;
 };
 
